#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import dplyr
#' @import ggplot2
#' @importFrom purrr set_names
#' @importFrom stats cor dist hclust var
#' @importFrom utils capture.output
#' @importFrom grDevices colorRampPalette dev.off
#' @importFrom stats cutree
#' @importFrom tgstat tgs_cor
#' @importFrom tgstat tgs_dist
#' @importFrom tibble remove_rownames column_to_rownames rownames_to_column has_rownames rowid_to_column as_tibble tibble
#'
#' @useDynLib tglkmeans
#' @importFrom Rcpp sourceCpp
## usethis namespace: end
NULL
